@@ -529,9 +529,14 @@ shinyServer(function(input, output, session) {
         } else if (-1 == userLog$model) {
             msg.box("Please validate model first.", "warning");
         } else {
-            wellPanel(h4('Download the analysis report'),
-                      radioButtons('format', '', c('PDF', 'HTML', 'Word')),
-                      downloadButton('btnDload'))
+          wellPanel(
+            msg.box('NOTE: If you want to download the report as a pdf, you will need to have
+                     both <a href="https://pandoc.org/installing.html" target="_blank"> pandoc</a>
+                     and <a href="https://miktex.org/" target="_blank">MiKTeX</a>
+                     installed on your computer.'),
+            h4('Download the analysis report'),
+            radioButtons('format', '', c('PDF', 'HTML', 'Word')),
+            downloadButton('btnDload'))
         }
     })
 
